@@ -12,6 +12,8 @@ patch_config = {
     'known_md5sums': [
         '5a51e4fbb38dac338e4444e6b713e9b3',
         '44d6b8258fb4fb9c849162704120ba53',
+# PR 1.3
+	'2c2713a25e323670cad57d5f856f0acf'
     ],
     'check_ranges': [
         (194380, 'f04f2de920b08de2'),
@@ -85,16 +87,16 @@ if __name__ == '__main__':
 
     if not patcher.check_md5sum(library):
         if not patcher.check_data(library):
-            message = "Your %s is not recognized. So I won't patch it." % (library,)
-	    subprocess.call(["dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteDialog string:\""+message+"\" uint32:0 string:\"OK\""],shell=True)
+            message = "Your %s is not recognized. So I won't patch it." % (library)
+	    subprocess.call(["dbus-send --system --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteDialog string:\""+message+"\" uint32:0 string:\"OK\""],shell=True)
 	    print message	
 	    sys.exit(1)
         if len(sys.argv) > 1 and sys.argv[1] == '--force':
-            message = "Patching an unrecognized %s. Please test your system before rebooting." % (library,)
+            message = "Patching an unrecognized %s. Please test your system before rebooting." % (library)
 	    print message	    
         else:
-	    message = "Your %s is not recognized, but it seems to match the patterns.\nRun '%s --force' to try patching anyway, but understand that\nTHIS MAY BREAK YOUR SYSTEM.  If you do, test your system thoroughly before rebooting." % (library,library,sys.argv[0])
-	    subprocess.call(["dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteDialog string:\""+message+"\" uint32:0 string:\"OK\""],shell=True)
+	    message = "Your %s is not recognized, but it seems to match the patterns.\nRun '%s --force' to try patching anyway, but understand that\nTHIS MAY BREAK YOUR SYSTEM.  If you do, test your system thoroughly before rebooting." % (library,sys.argv[0])
+	    subprocess.call(["dbus-send --system --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteDialog string:\""+message+"\" uint32:0 string:\"OK\""],shell=True)
 	    print message
 	    sys.exit(1)
 
